@@ -13,6 +13,9 @@ from tiddlywebplugins.instancer.util import get_tiddler_locations
 
 from tiddlywebwiki.instance import store_contents
 
+from tiddlywebplugins.console.instance import (store_contents as
+    console_store_contents)
+
 
 PACKAGE_NAME = 'tiddlywebwiki'
 BASE_TIDDLYWIKI = resource_filename(PACKAGE_NAME, 'resources/empty.html')
